/**
 * User: Clinton Begin
 * Date: Mar 8, 2003
 * Time: 12:00:57 PM
 */
package examples.sqlmap;

import com.ibatis.db.sqlmap.SqlMap;
import examples.domain.Account;
import examples.BaseExample;

import java.sql.*;
import java.util.*;

public class DynamicQueryExample extends BaseExample {

  public static void dynamicQueryExample()
      throws SQLException {
    // Get our configured SqlMap instance
    SqlMap sqlMap = SqlMapConfigExample.getSqlMap();

    try {
      // -- Start the transaction
      sqlMap.startTransaction();

      // -- This account will be used to build the dynamic SQL.
      // -- The effect is basically a query by example.
      Account account = new Account();
      account.setFirstName("Clinton");
      account.setLastName("Begin");

      // -- Get the List of Account objects that are like the account parameter.
      // -- Notice the API is exactly the same for normal mapped statements.
      List list = sqlMap.executeQueryForList("dynamicGetAccountList", account);

      for (int i = 0; i < list.size(); i++) {
        println("First/Last: " + list.get(i));
      }

      // -- Using the same query, we can search based on the email field only.
      account = new Account();
      account.setEmailAddress("%somewhere%");

      // -- Get the List of Account objects that are like the account parameter.
      list = sqlMap.executeQueryForList("dynamicGetAccountList", account);

      for (int i = 0; i < list.size(); i++) {
        println("Email/Like: " + list.get(i));
      }

      // -- Using the same query, we can search based on the id field only.
      account = new Account();
      account.setId(3);

      // -- Get the List of Account objects that are like the account parameter.
      list = sqlMap.executeQueryForList("dynamicGetAccountList", account);

      for (int i = 0; i < list.size(); i++) {
        println("ID/Equal: " + list.get(i));
      }

      // -- Commit the transaction
      sqlMap.commitTransaction();
    } catch (Exception e) {
      // -- With the introduction of stacked transactions, you'll
      // -- want to get in the habit of only calling rollback
      // -- in the event of an error.  Otherwise you might rollback
      // -- the next transaction in the stack.
      sqlMap.rollbackTransaction();
      throw (SQLException) e.fillInStackTrace();
    }
  }


}
