/**
 * User: Clinton Begin
 * Date: Mar 8, 2003
 * Time: 7:43:08 PM
 */
package examples.sqlmap;

import com.ibatis.common.beans.StaticBeanProbe;
import com.ibatis.db.sqlmap.SqlMap;
import examples.domain.Account;
import examples.BaseExample;

import java.sql.*;

public class InsertExample extends BaseExample {

  public static int insertExample()
      throws SQLException {
    // Get our configured SqlMap instance
    SqlMap sqlMap = SqlMapConfigExample.getSqlMap();

    int insertedId = getNextId();

    try {
      // -- Start the transaction
      sqlMap.startTransaction();

      // -- Create a new Account
      Account newAccount = new Account();
      newAccount.setId(insertedId);
      newAccount.setFirstName("Thomas");
      newAccount.setLastName("Anderson");
      newAccount.setEmailAddress("thomas.anderson@softwarecompany.com");

      // -- INSERT the new Account
      sqlMap.executeUpdate("insertAccount", newAccount);

      // -- Commit the transaction
      sqlMap.commitTransaction();

      // -- Check to see if the record was inserted correctly (just for testing)
      checkInsert(sqlMap, insertedId, newAccount);
    } catch (Exception e) {
      // -- With the introduction of stacked transactions, you'll
      // -- want to get in the habit of only calling rollback
      // -- in the event of an error.  Otherwise you might rollback
      // -- the next transaction in the stack.
      sqlMap.rollbackTransaction();
      throw (SQLException) e.fillInStackTrace();
    }
    return insertedId;
  }

  private static void checkInsert(SqlMap sqlMap, int insertedId, Account newAccount) throws SQLException {
    // -- Check to see if the record was inserted correctly (just for testing)
    sqlMap.startTransaction();
    Account account = (Account) sqlMap.executeQueryForObject("getAccount", new Integer(insertedId));
    if (account == null) throw new SQLException("Account was not inserted to the database correctly.");
    boolean isEqual = StaticBeanProbe.beanEquals(newAccount, account);
    if (!isEqual) throw new SQLException("Account was not inserted to the database correctly.");
    println("Inserted: " + account);
    sqlMap.commitTransaction();
  }


}
