/**
 * User: Clinton Begin
 * Date: Mar 8, 2003
 * Time: 11:59:49 AM
 */
package examples.sqlmap;

import com.ibatis.common.beans.StaticBeanProbe;
import com.ibatis.db.sqlmap.SqlMap;
import examples.domain.Account;
import examples.BaseExample;

import java.sql.*;

public class UpdateExample extends BaseExample {

  public static void updateExample(int id)
      throws SQLException {
    // Get our configured SqlMap instance
    SqlMap sqlMap = SqlMapConfigExample.getSqlMap();

    try {
      // -- Start the transaction
      sqlMap.startTransaction();

      // -- Get the existing account from the database
      Account newAccount = (Account) sqlMap.executeQueryForObject("getAccount", new Integer(id));

      // -- UPDATE the Account
      newAccount.setEmailAddress("neo@matrix.net");
      sqlMap.executeUpdate("updateAccount", newAccount);

      // -- Commit the transaction
      sqlMap.commitTransaction();

      // -- Check to see if the record was updated correctly (just for testing)
      checkUpdate(sqlMap, id, newAccount);
    } catch (Exception e) {
      // -- With the introduction of stacked transactions, you'll
      // -- want to get in the habit of only calling rollback
      // -- in the event of an error.  Otherwise you might rollback
      // -- the next transaction in the stack.
      sqlMap.rollbackTransaction();
      throw (SQLException) e.fillInStackTrace();
    }
  }

  private static void checkUpdate(SqlMap sqlMap, int id, Account newAccount) throws SQLException {
    // -- Check to see if the record was updated correctly (just for testing)
    sqlMap.startTransaction();
    Account account = (Account) sqlMap.executeQueryForObject("getAccount", new Integer(id));
    if (account == null) throw new SQLException("Account was not updated to the database correctly.");
    boolean isEqual = StaticBeanProbe.beanEquals(newAccount, account);
    if (!isEqual) throw new SQLException("Account was not updated to the database correctly.");
    println("Updated: " + account);
    sqlMap.commitTransaction();
  }

}
